/*
** A simple implementation of a resizing hash table
**
** Copyright (C) 2000 by Kevin L. Mitchell <klmitch@mit.edu>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
** @(#)$Id: hash_func.c,v 1.5 2000/12/07 16:48:36 klmitch Exp $
*/
#include "hash.h"
#include "hash_int.h"

RCSTAG("@(#)$Id: hash_func.c,v 1.5 2000/12/07 16:48:36 klmitch Exp $");

_h_ul
_hash_func(hash_tab *table, hash_key *key, _h_ul modulus)
{
  _h_ul hash = 0;
  int i;

  for (i = 0; i < key->hk_length; i++)
    hash = (hash * 257) + key->hk_key[i];
  /* New hash function courtesy of Nemesi */
  /* hash += hash + key->hk_key[i]; */

  return hash % modulus;
}
